@@ -1,17 +1,18 @@
 #!/usr/local/bin/ruby
 
 # Author::    Dirk Meyer
-# Copyright:: Copyright (c) 2008 - 2021 Dirk Meyer
+# Copyright:: Copyright (c) 2008 - 2025 Dirk Meyer
 # License::   Distributes under the same terms as Ruby
-# SPDX-FileCopyrightText: 2008-2021 Dirk Meyer
+# SPDX-FileCopyrightText: 2008-2025 Dirk Meyer
 # SPDX-License-Identifier: Ruby
 
 require 'resolv'
+require 'date'
 
 # Write something in a logfile with date and time.
 def write_log( *args )
   f = File.open( "ruby-dump.txt", "a+" )
-  f.write Time.now.to_s
+  f.write DateTime.now.to_s
   f.write " "
   f.write args.join(' ')
   f.write "\n"
@@ -21,11 +22,9 @@ end
 
 # Get the first IPv4 for a nameserver
 def getipv4server( hostname )
-  dns = Resolv::DNS.new
-  dns.each_address(hostname) do |address|
-    text = address.to_s
-    next if text.include?( ":" )
-    return text
+  Resolv::DNS.open do |dns|
+    list = dns.getresources( hostname, Resolv::DNS::Resource::IN::A )
+    return list.map( &:address ).first.to_s
   end
   nil
 end
@@ -174,6 +173,11 @@ class IrofferEvent
     end
   end
 
+  # Admin Command: RUBY version
+  def version
+    puts irconfig( "version" )
+    puts irconfig( "features" )
+  end
 end
 
 # eof
