@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2023 Dirk Meyer
+ * Copyright (C) 2004-2025 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,10 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-FileCopyrightText: 2004-2025 Dirk Meyer
  * SPDX-License-Identifier: GPL-2.0-only
  *
- * $Id: dinoex_config.c,v 1.265 2023/07/01 15:03:38 cvs Exp $
+ * $Id: dinoex_config.c,v 1.270 2025/12/07 08:37:21 cvs Exp $
  *
  */
 
@@ -111,7 +111,7 @@ static void dump_config_bool2(const char *name, unsigned int val)
     text = "yes"; /* NOTRANSLATE */
     break;
   }
-  dump_line("%s %s", name, text);
+  dump_line("%s %s", name, text); /* NOTRANSLATE */
 }
 
 /* dump an bool variable to logfile if defined */
@@ -264,6 +264,9 @@ static int config_find_typ(config_name_t config_name_f, const char *key, int bin
 }
 
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
+
 static int config_bool_anzahl = 0;
 static config_bool_typ config_parse_bool[] = {
 {"announce_size",          &gdata.announce_size,           0 }, /* NOTRANSLATE */
@@ -355,6 +358,8 @@ static config_bool_typ config_parse_bool[] = {
 {"xdcclistfileraw",        &gdata.xdcclistfileraw,         0 }, /* NOTRANSLATE */
 {NULL, NULL, 0 }};
 
+#pragma GCC diagnostic pop
+
 static const char *config_name_bool(unsigned int i)
 {
   return config_parse_bool[i].name;
@@ -462,7 +467,7 @@ static config_int_typ config_parse_int[] = {
 {"lowbdwth",                &gdata.lowbdwth,                0, 1000000, 1, 0 }, /* NOTRANSLATE */
 {"max_find",                &gdata.max_find,                0, 65000, 1, 0 }, /* NOTRANSLATE */
 {"max_uploads",             &gdata.max_uploads,             0, 65000, 1, 0 }, /* NOTRANSLATE */
-{"max_upspeed",             &gdata.max_upspeed,             0, 1000000, 4, 65000 }, /* NOTRANSLATE */
+{"max_upspeed",             &gdata.max_upspeed,             0, 1000000, 4, 0 }, /* NOTRANSLATE */
 {"maxidlequeuedperperson",  &gdata.maxidlequeuedperperson,  1, 1000000, 1, 1 }, /* NOTRANSLATE */
 {"maxqueueditemsperperson", &gdata.maxqueueditemsperperson, 1, 1000000, 1, 1 }, /* NOTRANSLATE */
 {"maxtransfersperperson",   &gdata.maxtransfersperperson,   1, 1000000, 1, 1 }, /* NOTRANSLATE */
@@ -622,6 +627,9 @@ static void reset_config_int(void)
 }
 
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
+
 /*  flags for strings
  0 -> literal string
  1 -> pathname
@@ -699,6 +707,8 @@ static config_string_typ config_parse_string[] = {
 {"xdccxmlfile",             &gdata.xdccxmlfile,             1 }, /* NOTRANSLATE */
 {NULL, NULL, 0 }};
 
+#pragma GCC diagnostic pop
+
 static const char *config_name_string(unsigned int i)
 {
   return config_parse_string[i].name;
@@ -724,19 +734,21 @@ static unsigned int set_config_string(const char *key, char *text)
 
   switch (config_parse_string[i].flags) {
   case 4:
-     if (strchr(text, ' ') != NULL) {
-       outerror(OUTERROR_TYPE_WARN,
-                "%s:%ld ignored %s '%s' because it contains spaces",
-                current_config, current_line, key, text);
-       return 0;
-     }
+    if (strchr(text, ' ') != NULL) {
+      outerror(OUTERROR_TYPE_WARN,
+               "%s:%ld ignored %s '%s' because it contains spaces",
+               current_config, current_line, key, text);
+      return 0;
+    }
 #ifndef NO_CRYPT
-     checkadminpass2(key, text);
+    checkadminpass2(key, text);
 #endif /* NO_CRYPT */
-     /* fallthrough */
+    /* fallthrough */
   case 1:
-     convert_to_unix_slash(text);
-     break;
+    convert_to_unix_slash(text);
+    break;
+  default:
+    break;
   }
   mydelete(*(config_parse_string[i].svar));
   *(config_parse_string[i].svar) = mystrdup(text);
@@ -780,6 +792,9 @@ static void reset_config_string(void)
 }
 
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
+
 /*  flags for lists
  0 -> literal string
  1 -> pathname
@@ -833,6 +848,8 @@ static config_list_typ config_parse_list[] = {
 {"xdcc_deny",               &gdata.xdcc_deny,               5 }, /* NOTRANSLATE */
 {NULL, NULL, 0 }};
 
+#pragma GCC diagnostic pop
+
 static const char *config_name_list(unsigned int i)
 {
   return config_parse_list[i].name;
@@ -927,6 +944,8 @@ static unsigned int set_config_list(const char *key, char *text)
   case 1:
     convert_to_unix_slash(text);
     break;
+  default:
+    break;
   }
   irlist_add_string(config_parse_list[i].list, text);
   return 0;
@@ -938,7 +957,7 @@ static size_t add_delimiter(char *val, size_t len)
     return 0;
   }
   return add_snprintf(val + len, maxtextlength - len,
-                      "%s", "," ); /* NOTRANSLATE */
+                      "%s", ","); /* NOTRANSLATE */
 }
 
 static char *print_config_list(const char *key)
@@ -1293,7 +1312,7 @@ static char *p_bandmax(void)
   char *text;
 
   text = mymalloc(maxtextlengthshort);
-  snprintf(text, maxtextlengthshort, "%u.0kB/s", gdata.maxb / 4); /* NOTRANSLATE */
+  snprintf(text, maxtextlengthshort, "%u.0kB/s", gdata.maxb / 4);
   return text;
 }
 
@@ -1791,6 +1810,8 @@ static void c_overallmaxspeeddaydays(const char * UNUSED(key), char *var)
     case 'S':
       gdata.overallmaxspeeddaydays |= 0x40;
       break;
+    default:
+      break;
     }
   }
 }
@@ -2311,7 +2332,8 @@ static char *p_user_nick(void)
 
 static char *p_version(void)
 {
-  return mystrdup( "iroffer-dinoex" " " VERSIONLONG ); /* NOTRANSLATE */
+  return mystrdup( "iroffer-dinoex"
+                   " " VERSIONLONG ); /* NOTRANSLATE */
 }
 
 static char *p_features(void)
@@ -2319,8 +2341,9 @@ static char *p_features(void)
   char *text;
 
   text = mymalloc(maxtextlength);
-  snprintf(text, maxtextlength, "iroffer-dinoex" " " VERSIONLONG FEATURES "%s%s",
-           gdata.hideos ? "" : " - ",
+  snprintf(text, maxtextlength, "iroffer-dinoex"
+           " " VERSIONLONG FEATURES "%s%s", /* NOTRANSLATE */
+           gdata.hideos ? "" : " - ", /* NOTRANSLATE */
            gdata.hideos ? "" : gdata.osstring);
   return text;
 }
@@ -2893,8 +2916,8 @@ static void config_expand_list_typ(config_name_t config_name_f, const char *key,
       continue;
 
     if (first != name)
-      tostdout(",");
-    tostdout(" %s", name);
+      tostdout(","); /* NOTRANSLATE */
+    tostdout(" %s", name); /* NOTRANSLATE */
   }
 }
 
@@ -2916,7 +2939,7 @@ size_t config_expand(char *buffer, size_t max, int print)
   if (found == 0)
     return 0;
   if (found == 1) {
-    snprintf(buffer, max, "%s ", first);
+    snprintf(buffer, max, "%s ", first); /* NOTRANSLATE */
     return strlen(first) - j + 1;
   }
   tostdout("** Args:");
