@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2023 Dirk Meyer
+ * Copyright (C) 2004-2025 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,10 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-FileCopyrightText: 2004-2025 Dirk Meyer
  * SPDX-License-Identifier: GPL-2.0-only
  *
- * $Id: dinoex_http.c,v 1.183 2023/07/01 15:03:38 cvs Exp $
+ * $Id: dinoex_http.c,v 1.187 2025/03/23 14:16:07 cvs Exp $
  *
  */
 
@@ -35,8 +35,6 @@
 
 #ifndef WITHOUT_HTTP
 
-#define MAX_WEBLIST_SIZE	(2 * 1024 * 1024)
-
 #define HTTP_DATE_LINE		"%a, %d %b %Y %T GMT"	/* NOTRANSLATE */
 
 typedef struct {
@@ -57,7 +55,9 @@ static const char * const http_header_status =
 "HTTP/1.1 %u OK\r\n" /* NOTRANSLATE */
 "Date: %s\r\n" /* NOTRANSLATE */
 "Last-Modified: %s\r\n" /* NOTRANSLATE */
-"Server: " "iroffer-dinoex" "/" VERSIONLONG "\r\n" /* NOTRANSLATE */
+"Server: " /* NOTRANSLATE */
+"iroffer-dinoex"
+"/" VERSIONLONG "\r\n" /* NOTRANSLATE */
 "Content-Type: %s%s\r\n" /* NOTRANSLATE */
 "Connection: close\r\n" /* NOTRANSLATE */
 "Content-Length: %" LLPRINTFMT "u\r\n" /* NOTRANSLATE */;
@@ -65,7 +65,9 @@ static const char * const http_header_status =
 static const char * const http_header_notfound =
 "HTTP/1.1 404 Not Found\r\n" /* NOTRANSLATE */
 "Date: %s\r\n" /* NOTRANSLATE */
-"Server: " "iroffer-dinoex" "/" VERSIONLONG "\r\n" /* NOTRANSLATE */
+"Server: " /* NOTRANSLATE */
+"iroffer-dinoex"
+"/" VERSIONLONG "\r\n" /* NOTRANSLATE */
 "Content-Type: text/plain\r\n" /* NOTRANSLATE */
 "Connection: close\r\n" /* NOTRANSLATE */
 "Content-Length: 13\r\n" /* NOTRANSLATE */
@@ -76,7 +78,9 @@ static const char * const http_header_notfound =
 static const char * const http_header_forbidden =
 "HTTP/1.1 403 Forbidden\r\n" /* NOTRANSLATE */
 "Date: %s\r\n" /* NOTRANSLATE */
-"Server: " "iroffer-dinoex" "/" VERSIONLONG "\r\n" /* NOTRANSLATE */
+"Server: " /* NOTRANSLATE */
+"iroffer-dinoex"
+"/" VERSIONLONG "\r\n" /* NOTRANSLATE */
 "Content-Type: text/plain\r\n" /* NOTRANSLATE */
 "Connection: close\r\n" /* NOTRANSLATE */
 "Content-Length: 13\r\n" /* NOTRANSLATE */
@@ -226,6 +230,9 @@ static const char *html_mime(const char *file)
   return http_magic[i].m_mime;
 }
 
+#ifndef __clang__
+#pragma GCC diagnostic ignored "-Wstringop-truncation"
+#endif
 static size_t html_encode(char *buffer, size_t max, const char *src)
 {
   char *dest = buffer;
@@ -1701,7 +1708,8 @@ static void h_html_index(http * const h)
   (void)add_snprintf(tlabel + len, maxtextlength - len, "%6s %s\n", tempstr, "Traffic this month");
   mydelete(tempstr);
   h_respond(h, "<td title=\"%s\">%s</td>\n", /* NOTRANSLATE */
-            tlabel, "iroffer-dinoex" " " VERSIONLONG);
+            tlabel, "iroffer-dinoex"
+            " " VERSIONLONG); /* NOTRANSLATE */
   mydelete(tlabel);
 
   tempstr = mymalloc(maxtextlength);
@@ -2116,7 +2124,7 @@ static void h_parse(http * const h, char *body)
 
   if (gdata.http_dir) {
     tempstr = mymalloc(maxtextlength);
-    snprintf(tempstr, maxtextlength, "%s%s", gdata.http_dir, h->url);
+    snprintf(tempstr, maxtextlength, "%s%s", gdata.http_dir, h->url); /* NOTRANSLATE */
     tmp = strchr(tempstr, '?' );
     if (tmp != NULL)
       *tmp = 0;
