@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2021 Dirk Meyer
+ * Copyright (C) 2004-2025 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,10 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-FileCopyrightText: 2004-2025 Dirk Meyer
  * SPDX-License-Identifier: GPL-2.0-only
  *
- * $Id: dinoex_irc.c,v 1.117 2021/09/19 10:10:12 cvs Exp $
+ * $Id: dinoex_irc.c,v 1.119 2025/02/05 19:04:43 cvs Exp $
  *
  */
 
@@ -677,6 +677,12 @@ static  const char *irc_resolved_errormsg[] = {
 };
 #endif
 
+#if defined(_OS_CYGWIN)
+#if !defined(WEXITED)
+#define WEXITED	16	/* Wait for exited processes. */
+#endif
+#endif /* _OS_CYGWIN */
+
 /* collect the the DNS resolution from the child process */
 void irc_resolved(void)
 {
@@ -1088,7 +1094,7 @@ static void irc_001(ir_parseline_t *ipl)
   for (tptr = irlist_get_head(&(gnetwork->server_connected_raw));
        tptr;
        tptr = irlist_get_next(tptr)) {
-    writeserver(WRITESERVER_NORMAL, "%s", tptr);
+    writeserver(WRITESERVER_NORMAL, "%s", tptr); /* NOTRANSLATE */
   }
 
   /* nickserv */
