@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2023 Dirk Meyer
+ * Copyright (C) 2004-2025 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,10 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-FileCopyrightText: 2004-2025 Dirk Meyer
  * SPDX-License-Identifier: GPL-2.0-only
  *
- * $Id: dinoex_jobs.c,v 1.240 2023/07/01 15:03:38 cvs Exp $
+ * $Id: dinoex_jobs.c,v 1.243 2025/02/05 20:45:31 cvs Exp $
  *
  */
 
@@ -1657,7 +1657,7 @@ static void xdcc_save_xml(void)
   write_asc_plain(xmlbuf, 4, "banduse", tempstr); /* NOTRANSLATE */
   mydelete(tempstr);
   tempstr = mymalloc(maxtextlengthshort);
-  snprintf(tempstr, maxtextlengthshort, "%u.0kB/s", gdata.maxb / 4); /* NOTRANSLATE */
+  snprintf(tempstr, maxtextlengthshort, "%u.0kB/s", gdata.maxb / 4);
   write_asc_plain(xmlbuf, 4, "bandmax", tempstr); /* NOTRANSLATE */
   mydelete(tempstr);
   write_string(xmlbuf, "  </bandwidth>\n"); /* NOTRANSLATE */
@@ -1715,7 +1715,9 @@ static void xdcc_save_xml(void)
   gnetwork = backup;
 
   write_string(xmlbuf, "  <stats>\n"); /* NOTRANSLATE */
-  write_asc_plain(xmlbuf, 4, "version", "iroffer-dinoex" " " VERSIONLONG ); /* NOTRANSLATE */
+  write_asc_plain(xmlbuf, 4, "version", /* NOTRANSLATE */
+                  "iroffer-dinoex"
+                  " " VERSIONLONG ); /* NOTRANSLATE */
   tempstr = mymalloc(maxtextlengthshort);
   tempstr = getuptime(tempstr, 1, gdata.startuptime, maxtextlengthshort);
   write_asc_plain(xmlbuf, 4, "uptime", tempstr); /* NOTRANSLATE */
@@ -1873,7 +1875,7 @@ void send_periodicmsg(void)
       continue;
 
     pm->pm_next_time = gdata.curtime + (pm->pm_time * 60);
-    privmsg(pm->pm_nick, "%s", pm->pm_msg);
+    privmsg(pm->pm_nick, "%s", pm->pm_msg); /* NOTRANSLATE */
   }
   gnetwork = NULL;
 }
