@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2019-2021 Dirk Meyer
+ * Copyright (C) 2019-2025 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,10 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * SPDX-FileCopyrightText: 2019-2021 Dirk Meyer
+ * SPDX-FileCopyrightText: 2019-2025 Dirk Meyer
  * SPDX-License-Identifier: GPL-2.0-only
  *
- * $Id: dinoex_maxminddb.c,v 1.7 2021/09/19 10:10:12 cvs Exp $
+ * $Id: dinoex_maxminddb.c,v 1.9 2025/12/07 07:29:44 cvs Exp $
  *
  */
 
@@ -28,7 +28,10 @@
 
 #ifdef USE_MAXMINDDB
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpadded"
 #include <maxminddb.h>
+#pragma GCC diagnostic pop
 
 typedef struct {
   const char *gi;
@@ -37,7 +40,7 @@ typedef struct {
   char code[8];
 } ir_maxminddb;
 
-static ir_maxminddb maxminddb_data = { NULL };
+static ir_maxminddb maxminddb_data;
 
 static time_t maxminddb_time(const char *name)
 {
@@ -221,6 +224,13 @@ unsigned int http_check_maxminddb(const struct sockaddr *const sa, const char *h
 void maxminddb_shutdown(void)
 {
   maxminddb_close(&maxminddb_data);
+  bzero(&maxminddb_data, sizeof(maxminddb_data));
+}
+
+/* initialize GeoIP */
+void maxminddb_init(void)
+{
+  bzero(&maxminddb_data, sizeof(maxminddb_data));
 }
 
 #endif /* USE_MAXMINDDB */
