@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2020 Dirk Meyer
+ * Copyright (C) 2004-2025 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,10 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-FileCopyrightText: 2004-2025 Dirk Meyer
  * SPDX-License-Identifier: GPL-2.0-only
  *
- * $Id: dinoex_misc.c,v 1.365 2021/12/16 17:25:52 cvs Exp $
+ * $Id: dinoex_misc.c,v 1.368 2025/12/07 08:37:21 cvs Exp $
  *
  */
 
@@ -461,6 +461,9 @@ void config_dinoex(void)
 #ifndef WITHOUT_HTTP
   h_setup_listen();
 #endif /* WITHOUT_HTTP */
+#ifdef USE_MAXMINDDB
+  maxminddb_init();
+#endif /* USE_MAXMINDDB */
   global_defaults();
 }
 
@@ -1053,6 +1056,8 @@ const char *text_connectionmethod(how_e how)
     return "wingate"; /* NOTRANSLATE */
   case how_custom:
     return "custom"; /* NOTRANSLATE */
+  default:
+    break;
   }
   return "unknown";
 }
@@ -1274,7 +1279,7 @@ void dump_slow_context(void)
       offset *= 1000000;
       offset += c->tv.tv_usec - last->tv.tv_usec;
       if (offset > 171000) {
-        ioutput(OUT_S|OUT_L, COLOR_NO_COLOR, "%s", lastline);
+        ioutput(OUT_S|OUT_L, COLOR_NO_COLOR, "%s", lastline); /* NOTRANSLATE */
         show = 1;
       }
     }
@@ -1289,7 +1294,7 @@ void dump_slow_context(void)
              c->line,
              (unsigned long)c->tv.tv_sec,
              (unsigned long)c->tv.tv_usec);
-    ioutput(OUT_S|OUT_L, COLOR_NO_COLOR, "%s", lastline);
+    ioutput(OUT_S|OUT_L, COLOR_NO_COLOR, "%s", lastline); /* NOTRANSLATE */
   }
   mydelete(lastline);
 }
