@@ -1,15 +1,18 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2018 Dirk Meyer
+ * Copyright (C) 2004-2021 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
  *
  * If you received this file without documentation, it can be
- * downloaded from http://iroffer.net/
+ * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_statefile.c,v 1.37 2018/12/20 07:14:05 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_statefile.c,v 1.39 2021/12/16 17:25:09 cvs Exp $
  *
  */
 
@@ -167,7 +170,7 @@ static void read_statefile_md5info(statefile_hdr_t *hdr, const char *tag, xdcc *
     xd->st_size = (off_t)((((ir_uint64)ntohl(md5sum_info->st_size.upper)) << 32) | ((ir_uint64)ntohl(md5sum_info->st_size.lower)));
     xd->st_dev  = (dev_t)((((ir_uint64)ntohl(md5sum_info->st_dev.upper)) << 32) | ((ir_uint64)ntohl(md5sum_info->st_dev.lower)));
     xd->st_ino  = (ino_t)((((ir_uint64)ntohl(md5sum_info->st_ino.upper)) << 32) | ((ir_uint64)ntohl(md5sum_info->st_ino.lower)));
-    netval = (ir_int32)md5sum_info->mtime;
+    netval = md5sum_info->mtime;
     xd->mtime   = ntohl(netval);
     memcpy(xd->md5sum, md5sum_info->md5sum, sizeof(MD5Digest));
     return;
@@ -593,10 +596,10 @@ static void write_statefile_xdccs(ir_moutput_t *bout)
   unsigned char *next;
   xdcc *xd;
   statefile_item_md5sum_info32_t *md5sum_info;
-  unsigned int has_desc = 1;
-  unsigned int has_note = 1;
-  unsigned int has_minspeed;
-  unsigned int has_maxspeed;
+  int has_desc = 1;
+  int has_note = 1;
+  int has_minspeed;
+  int has_maxspeed;
   size_t length;
 
   updatecontext();
