@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2021 Dirk Meyer
+ * Copyright (C) 2004-2025 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,10 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-FileCopyrightText: 2004-2025 Dirk Meyer
  * SPDX-License-Identifier: GPL-2.0-only
  *
- * $Id: dinoex_transfer.c,v 1.75 2021/09/19 10:10:12 cvs Exp $
+ * $Id: dinoex_transfer.c,v 1.76 2025/02/05 19:04:43 cvs Exp $
  *
  */
 
@@ -206,7 +206,7 @@ unsigned int t_check_ip_access(transfer *const tr)
     if (!verify_cidr(&gdata.xdcc_allow, &(tr->con.remote))) {
       msg = "Sorry, downloads to your IP not allowed, ask owner.";
       t_closeconn(tr, msg, 0);
-      ioutput(OUT_S|OUT_L|OUT_D, COLOR_NO_COLOR, "%s", msg);
+      ioutput(OUT_S|OUT_L|OUT_D, COLOR_NO_COLOR, "%s", msg); /* NOTRANSLATE */
       return 1;
     }
   }
@@ -214,7 +214,7 @@ unsigned int t_check_ip_access(transfer *const tr)
   if (verify_cidr(&gdata.xdcc_deny, &(tr->con.remote))) {
     msg = "Sorry, downloads to your IP denied, ask owner.";
     t_closeconn(tr, msg, 0);
-    ioutput(OUT_S|OUT_L|OUT_D, COLOR_NO_COLOR, "%s", msg);
+    ioutput(OUT_S|OUT_L|OUT_D, COLOR_NO_COLOR, "%s", msg); /* NOTRANSLATE */
     return 1;
   }
   return 0;
