@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2023 Dirk Meyer
+ * Copyright (C) 2004-2025 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,10 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-FileCopyrightText: 2004-2025 Dirk Meyer
  * SPDX-License-Identifier: GPL-2.0-only
  *
- * $Id: dinoex_utilities.c,v 1.135 2023/07/01 15:03:38 cvs Exp $
+ * $Id: dinoex_utilities.c,v 1.138 2025/12/07 08:37:21 cvs Exp $
  *
  */
 
@@ -534,8 +534,8 @@ void removenonprintablefile(char *str)
     case ' ':
       if (gdata.spaces_in_filenames)
         break;
-      /* fallthrough */
-    case '|':
+      __attribute__((fallthrough));
+    case '|': __attribute__((fallthrough));
     case ':':
     case '?':
     case '*':
@@ -549,6 +549,8 @@ void removenonprintablefile(char *str)
     case 0x7FU:
       *copy = '_';
       break;
+    default:
+      break;
     }
     last = *copy;
   }
@@ -578,6 +580,8 @@ char *getsendname(const char * const full)
     case ' ':
       spaced = 1;
       break;
+    default:
+      break;
     }
   }
 
@@ -610,6 +614,8 @@ char *getsendname(const char * const full)
     case 0x7FU:
       copy[i] = '_';
       break;
+    default:
+      break;
     }
   }
   return copy;
@@ -1005,7 +1011,7 @@ add_snprintf(char * str, size_t size, const char * format, ...)
 /* sort a linked list with selection sort */
 void irlist_sort2(irlist_t *list, int (*cmpfunc)(const void *a, const void *b))
 {
-  irlist_t newlist = {0, 0, 0};
+  irlist_t newlist = EMPTY_IRLIST;
   void *cur;
   void *ltry;
   void *last;
@@ -1042,7 +1048,7 @@ void irlist_sort2(irlist_t *list, int (*cmpfunc)(const void *a, const void *b))
 /* sort a linked list with merge sort */
 void irlist_sort2(irlist_t *list, int (*cmpfunc)(const void *a, const void *b))
 {
-  irlist_t newlist = {0, 0, 0};
+  irlist_t newlist = EMPTY_IRLIST;
   irlist_t *p;
   irlist_t *q;
   irlist_t *e;
