@@ -96,8 +96,7 @@ compare_right(nat_char const *a, nat_char const *b)
 	  } else if (!*a  &&  !*b)
 	       return bias;
      }
-
-     return 0;
+     /* notreached */
 }
 
 
@@ -118,8 +117,7 @@ compare_left(nat_char const *a, nat_char const *b)
 	  if (*a > *b)
 	       return +1;
      }
-	  
-     return 0;
+     /* notreached */
 }
 
 
